# Changelog

## Version 0.1.5
- Update lumeo-bulk-deploy to handle live stream deployments

## Version 0.1.4
- Refactored library and package structure
- New helper scripts : 
  - lumeo-scripts : list all scripts
  - lumeo-bulk-deploy : upload files and queue deployments for processing
  - lumeo-avigilon-import-cameras : import cameras from Avigilon
  - lumeo-verkada-import-cameras : import cameras from Verkada
  - lumeo-rhombus-copy-footage : copy footage from Rhombus and format correctly for Lumeo
  - lumeo-custom-function-create-repo : create a repo for a custom function

## Version 0.0.3 (development)
- Add scripts to import cameras and process videos in bulk
- Reorganize custom code node helpers under `lumeo.pipeline`
